@@ -8,13 +8,13 @@
 //
 // I release my code as GPL, but see the other headers and the README
 
-#ifndef __LORENZKSCRN_H__
-#define __LORENZKSCRN_H__
+#ifndef LORENZKSCRN_H
+#define LORENZKSCRN_H
 
 #include <qtimer.h>
 #include <qcolor.h>
 #include <kscreensaver.h>
-#include <kdialogbase.h>
+#include <kdialog.h>
 
 // See lorenz.cpp for this private class
 class Matrix3D;
@@ -34,12 +34,11 @@ public:
     void updateMatrix();
     void newEpoch();
 
-protected slots:
-    void drawOnce();
+protected:
+    void paintEvent(QPaintEvent *);
 
 protected:
     QTimer timer;
-    int colorContext;
 
 private:
     void readSettings();
@@ -53,11 +52,11 @@ private:
 
 class QSlider;
 
-class KLorenzSetup : public KDialogBase
+class KLorenzSetup : public KDialog
 {
     Q_OBJECT
 public:
-    KLorenzSetup(QWidget *parent = 0, const char *name = 0 );
+    KLorenzSetup(QWidget *parent = 0 );
     ~KLorenzSetup();
 
 protected:
