@@ -66,27 +66,32 @@ int main( int argc, char *argv[] )
 // dialog to setup screen saver parameters
 //
 KWaveSetup::KWaveSetup( QWidget *parent)
-	: QDialog( parent )
+	: KDialog( parent )
 {
-	setupUi(this);
 	setModal(true);
+        setCaption(i18n( "Bitmap Flag Setup" ));
+        setButtons(Ok|Cancel|Help);
+        setDefaultButton(Ok);
+        setButtonText( Help, i18n( "A&bout" ) );
+        QWidget *main = new QWidget(this);
+        setMainWidget(main);
+        cfg = new WaveWidget(main);
 	readSettings();
 
-	preview->setFixedSize( 220, 170 );
+	cfg->preview->setFixedSize( 220, 170 );
 
         QPalette palette;
-        palette.setColor( preview->backgroundRole(), Qt::black );
-        preview->setPalette( palette );
-	preview->setAutoFillBackground(true);
+        palette.setColor( cfg->preview->backgroundRole(), Qt::black );
+        cfg->preview->setPalette( palette );
+	cfg->preview->setAutoFillBackground(true);
 
-	preview->show();    // otherwise saver does not get correct size
-	saver = new KWaveSaver( preview->winId() );
+	cfg->preview->show();    // otherwise saver does not get correct size
+	saver = new KWaveSaver( cfg->preview->winId() );
 
-	connect( PushButton1, SIGNAL( clicked() ), SLOT( slotOkPressed() ) );
-	connect( PushButton2, SIGNAL( clicked() ), SLOT( reject() ) );
-	connect( PushButton3, SIGNAL( clicked() ), SLOT( aboutPressed() ) );
-	connect(  SpinBox1, SIGNAL( valueChanged(int)), saver, SLOT( updateSize(int)));
-	connect( RadioButton1, SIGNAL( toggled(bool)), saver, SLOT( doStars(bool)));
+	connect( this, SIGNAL( okClicked() ), SLOT( slotOkPressed() ) );
+	connect( this, SIGNAL( helpClicked() ), SLOT( aboutPressed() ) );
+	connect(  cfg->SpinBox1, SIGNAL( valueChanged(int)), saver, SLOT( updateSize(int)));
+	connect( cfg->RadioButton1, SIGNAL( toggled(bool)), saver, SLOT( doStars(bool)));
 
 }
 
