@@ -1,5 +1,5 @@
 /*
-  $Id: icewm.h 489039 2005-12-16 22:05:28Z giessl $
+  $Id: icewm.h 474856 2005-10-27 12:44:04Z mlaurent $
 
   Gallium-IceWM themeable KWin client
 
@@ -42,12 +42,23 @@
 #ifndef __KDEGALLIUM_ICEWM_H
 #define __KDEGALLIUM_ICEWM_H
 
-#include <qbutton.h>
+#include <q3button.h>
 #include <qlayout.h>
+//Added by qt3to4:
+#include <QPixmap>
+#include <QPaintEvent>
+#include <QGridLayout>
+#include <QEvent>
+#include <QBoxLayout>
+#include <QLabel>
+#include <QShowEvent>
+#include <QResizeEvent>
+#include <QMouseEvent>
 #include <kpixmap.h>
 #include <kdecoration.h>
 #include <kdecorationfactory.h>
-#include <qbutton.h>
+#include <kcommondecoration.h>
+#include <q3button.h>
 class QLabel;
 class QSpacerItem;
 class QBoxLayout;
@@ -60,7 +71,7 @@ class IceWMClient;
 // Pixmap group
 enum { InActive=0, Active };
 // Pixmap stretching mode
-enum { Vertical=0, Horizontal=1 };
+enum { Qt::Vertical=0, Qt::Horizontal=1 };
 
 
 // Handles the resetClients() signal from the Options class,
@@ -96,12 +107,12 @@ class ThemeHandler: public KDecorationFactory
 };
 
 
-class IceWMButton : public QButton
+class IceWMButton : public Q3Button
 {
 	public:
 		IceWMButton( IceWMClient *parent=0, const char *name=0,
 					 QPixmap* (*p)[2]=0L, bool isToggle=false,
-					 const QString& tip=NULL, const int realizeBtns = LeftButton );
+					 const QString& tip=NULL, const int realizeBtns = Qt::LeftButton );
 		void setTipText(const QString &tip);
 		void  usePixmap( QPixmap* (*p)[2] );
 		QSize sizeHint() const;
@@ -138,7 +149,6 @@ class IceWMClient : public KDecoration
 	    void paintEvent( QPaintEvent* );
 	    void showEvent( QShowEvent* );
 	    void mouseDoubleClickEvent( QMouseEvent * );
-	    void wheelEvent( QWheelEvent * );
 	    virtual void captionChange();
 	    virtual void maximizeChange();
 	    virtual void shadeChange();
